function prionH=logP(vecA,cA,sigA,nuA,signA,A_rho,B_rho,n)
% ===================================================
% By Christiane Baumeister and James D. Hamilton (Sept 2013)
% returns log of prior evaluated at the point vecA
% cA = vector of location params
% sigA = vector of scale params
% nuA = vector of degrees of freedom
% signA(i) = 1 if element i restricted to be positive
%          = -1 if element i restricted to be negative
%          = 0  if element i not restricted
% ===================================================
x = (vecA(1:end-1,1) - cA)./sigA;
fpdf = tpdf(x,nuA)./sigA;
Fcdf = 0.5*(1 + (1 - abs(signA)) + signA) - signA.*tcdf(-cA./sigA,nuA);
prion = sum(log(fpdf) - log(Fcdf)) + log(beta_prior(vecA(end,1),A_rho,B_rho));

if n==3
    h1 = vecA(2,1) + vecA(3,1)*vecA(5,1)*(1-vecA(6,1));
    zeta_h1 = 1;       % overall weight put on the prior for h1
    sig_h1 = 1;        % scale parameter of the prior (obtained by simulation: see simulate_h.m in 'prior_toolbox')
    mu_h1 = -0.1;      % location parameter of the prior (obtained by simulation: see simulate_h.m in 'prior_toolbox')
    nu_h1 = 3;         % degrees of freedom
    lam_h1 = -4;       % determines asymmetry of the prior
    fh1 = zeta_h1*(log(tpdf((h1-mu_h1)/sig_h1,nu_h1)) + log(normcdf(lam_h1*h1/sig_h1)));

    h2 = vecA(1,1)*vecA(3,1) / (vecA(1,1)-vecA(2,1));
    zeta_h2 = 1;       % overall weight put on the prior for h2
    sig_h2 = 0.5;      % scale parameter of the prior
    mu_h2 = -0.3;      % loction parameter of the prior
    nu_h2 = 3;         % degrees of freedom
    lam_h2 = -2;       % determines asymmetry of the prior
    fh2 = zeta_h2*(log(tpdf((h2-mu_h2)/sig_h2,nu_h2)) + log(normcdf(lam_h2*h2/sig_h2)));

    prionH = prion + fh1 + fh2;

elseif n==6
    A = setA(vecA,n);
    h1 = det(A);
    zeta_h1 = 1;       % overall weight put on the prior for h1
    sig_h1 = 1;        % scale parameter of the prior (obtained by simulation: see simulate_h.m in 'prior_toolbox')
    mu_h1 = 0.1;       % location parameter of the prior (obtained by simulation: see simulate_h.m in 'prior_toolbox')
    nu_h1 = 3;         % degrees of freedom
    lam_h1 = 4;        % determines asymmetry of the prior
    fh1 = zeta_h1*(log(tpdf((h1-mu_h1)/sig_h1,nu_h1)) + log(normcdf(lam_h1*h1/sig_h1)));

    H = inv(A);
    H_tilde = det(A)*inv(A);   %adjoint
    h2 = H_tilde(1,3) / H_tilde(3,3);
    %equivalent:
    %h2 = H(1,3) / H(3,3);  % because det(A) cancels
    zeta_h2 = 1;       % overall weight put on the prior for h2
    sig_h2 = 0.5;      % scale parameter of the prior
    mu_h2 = -0.3;      % loction parameter of the prior
    nu_h2 = 3;         % degrees of freedom
    lam_h2 = -2;       % determines asymmetry of the prior
    fh2 = zeta_h2*(log(tpdf((h2-mu_h2)/sig_h2,nu_h2)) + log(normcdf(lam_h2*h2/sig_h2)));

    h13 = H(1,3);
    zeta_h13 = 1;      % overall weight put on the prior for h2
    sig_h13 = 1;       % scale parameter of the prior
    mu_h13 = 0;        % loction parameter of the prior
    nu_h13 = 3;        % degrees of freedom
    lam_h13 = -5000;   % determines asymmetry of the prior
    fh13 = zeta_h13*(log(tpdf((h13-mu_h13)/sig_h13,nu_h13)) + log(normcdf(lam_h13*h13/sig_h13)));

    h23 = H(2,3);
    zeta_h23 = 1;      % overall weight put on the prior for h2
    sig_h23 = 1;       % scale parameter of the prior
    mu_h23 = 0;        % loction parameter of the prior
    nu_h23 = 3;        % degrees of freedom
    lam_h23 = -5000;   % determines asymmetry of the prior
    fh23 = zeta_h23*(log(tpdf((h23-mu_h23)/sig_h23,nu_h23)) + log(normcdf(lam_h23*h23/sig_h23)));

    h33 = H(3,3);
    zeta_h33 = 1;      % overall weight put on the prior for h2
    sig_h33 = 1;       % scale parameter of the prior
    mu_h33 = 0;        % loction parameter of the prior
    nu_h33 = 3;        % degrees of freedom
    lam_h33 = 5000;    % determines asymmetry of the prior
    fh33 = zeta_h33*(log(tpdf((h33-mu_h33)/sig_h33,nu_h33)) + log(normcdf(lam_h33*h33/sig_h33)));

    h43 = H(4,3);
    zeta_h43 = 1;      % overall weight put on the prior for h2
    sig_h43 = 1;       % scale parameter of the prior
    mu_h43 = 0;        % loction parameter of the prior
    nu_h43 = 3;        % degrees of freedom
    lam_h43 = 5000;    % determines asymmetry of the prior
    fh43 = zeta_h43*(log(tpdf((h43-mu_h43)/sig_h43,nu_h43)) + log(normcdf(lam_h43*h43/sig_h43)));

    h53 = H(5,3);
    zeta_h53 = 1;      % overall weight put on the prior for h2
    sig_h53 = 1;       % scale parameter of the prior
    mu_h53 = 0;        % loction parameter of the prior
    nu_h53 = 3;        % degrees of freedom
    lam_h53 = -5000;   % determines asymmetry of the prior
    fh53 = zeta_h53*(log(tpdf((h53-mu_h53)/sig_h53,nu_h53)) + log(normcdf(lam_h53*h53/sig_h53)));

    h63 = H(6,3);
    zeta_h63 = 1;      % overall weight put on the prior for h2
    sig_h63 = 1;       % scale parameter of the prior
    mu_h63 = 0;        % loction parameter of the prior
    nu_h63 = 3;        % degrees of freedom
    lam_h63 = -5000;   % determines asymmetry of the prior
    fh63 = zeta_h63*(log(tpdf((h63-mu_h63)/sig_h63,nu_h63)) + log(normcdf(lam_h63*h63/sig_h63)));

    prionH = prion + fh1 + fh2 + fh13 + fh23 + fh33 + fh43 + fh53 + fh63;
    
end



