%%% This program generates draws for variance decompositions 
%%% By Christiane Baumeister and James D. Hamilton (Aug 2015)

% To be run after running irf.m, which should have set variables including:
%  psi_invA = [n x n x (hmax+nlags) x nuse] array which includes structural
%     impulse-response matrices
%     dimension 1: variable affected
%     dimension 2: shock whose effect is sought
%     dimension 3: hmax + s component is effect of shock after s periods (s = 0,1,..,hmax-1)
%     dimension 4: indexes the Monte Carlo draw of the parameters
% note psi_invA is the cumulation of IRFs if kcum = 1
%  invdDraw = (n x nuse) array of inverse of structural variances
%     invdDraw(i,m) = inverse of variance of ith structural equation associated with mth parameter draw

% output:
% Q = [n x n x (hmax+nlags) x nuse] array of total MSE coming from each shock
%     dimension 1: variable affected
%     dimension 2: shock whose effect is sought
%     dimension 3: hmax + s component is MSE of s-period-ahead forecast (s = 0,1,..,hmax-1)
%     dimension 4: indexes the Monte Carlo draw of the parameters


Q = zeros(n,n,hmax+nlags,nuse);

% ===========================================================
% 'Generating draws for variance decomposition'
isim = 0;
while isim < nuse
    isim = isim + 1;
    if (isim/10000) == floor(isim/10000)
        isim
    end
    hsim = 0;
    while hsim < hmax
        H = squeeze(psi_invA0(:,:,nlags+hsim,isim));
        % psi_invA0 has cumulated IRF  when kcum = 1, regular when kcum = 0
        j = 0;
        while j < n
            j = j+1;
            Q(:,j,nlags+hsim,isim) = Q(:,j,nlags+hsim-1,isim) + (1/invdDraw(j,isim))*H(:,j).*H(:,j);
        end
    hsim = hsim +1;
    end
end

% ============================================================
% Report results
index0 = round(0.5*nuse);
index1 = round(0.025*nuse);
index2 = round((1 - 0.025)*nuse);

H0 = zeros(n,n,hmax);
H1 = zeros(n,n,hmax);
H2 = zeros(n,n,hmax);
    for i = 1:n
        for j = 1:n
           K = squeeze(Q(i,j,nlags:nlags+hmax-1,:));
           K = sort(K,2);
           %H0(i,j,:) = mean(K,2);     % posterior mean
           H0(i,j,:) = K(:,index0);    % posterior median
           H1(i,j,:) = K(:,index1);
           H2(i,j,:) = K(:,index2);
        end
    end

vd5=H0(:,:,5);
perc1=vd5(1,:)./sum(vd5(1,:));
perc2=vd5(2,:)./sum(vd5(2,:));
perc3=vd5(3,:)./sum(vd5(3,:));
perc=[perc1;perc2;perc3];

vd5u=H2(:,:,5);
vd5l=H1(:,:,5);
    
% report final results   
disp(['Horizon ' num2str(5)])
disp('median')
disp(round(vd5,2))
disp('fraction')
disp(round(100*perc,2))
disp('lower 2.5%')
disp(round(vd5l,2))
disp('upper 2.5%')
disp(round(vd5u,2))

clear Q
